Documentation
¶
Index ¶
- func NewCmdCreateProject(commonOpts *opts.CommonOptions) *cobra.Command
- func NewCmdCreateQuickstart(commonOpts *opts.CommonOptions) *cobra.Command
- func NewCmdCreateSpring(commonOpts *opts.CommonOptions) *cobra.Command
- type CreateProjectOptions
- type CreateProjectWizardOptions
- type CreateQuickstartOptions
- type CreateSpringOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdCreateProject ¶
func NewCmdCreateProject(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdCreateProject creates a command object for the "create" command
func NewCmdCreateQuickstart ¶
func NewCmdCreateQuickstart(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdCreateQuickstart creates a command object for the "create" command
func NewCmdCreateSpring ¶
func NewCmdCreateSpring(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdCreateSpring creates a command object for the "create" command
Types ¶
type CreateProjectOptions ¶
type CreateProjectOptions struct {
importcmd.ImportOptions
OutDir string
DisableImport bool
GithubAppInstalled bool
}
CreateProjectOptions contains the command line options
func (*CreateProjectOptions) ImportCreatedProject ¶
func (o *CreateProjectOptions) ImportCreatedProject(outDir string) error
DoImport imports the project created at the given directory
type CreateProjectWizardOptions ¶
type CreateProjectWizardOptions struct {
options.CreateOptions
}
CreateProjectWizardOptions the options for the command
func (*CreateProjectWizardOptions) Run ¶
func (o *CreateProjectWizardOptions) Run() error
Run implements the command
type CreateQuickstartOptions ¶
type CreateQuickstartOptions struct {
CreateProjectOptions
GitHubOrganisations []string
Filter quickstarts.QuickstartFilter
GitProvider gits.GitProvider
GitHost string
IgnoreTeam bool
}
CreateQuickstartOptions the options for the create quickstart command
func (*CreateQuickstartOptions) CreateQuickStart ¶
func (o *CreateQuickstartOptions) CreateQuickStart(q *quickstarts.QuickstartForm) error
CreateQuickStart helper method to create a quickstart from a quickstart resource
func (*CreateQuickstartOptions) Run ¶
func (o *CreateQuickstartOptions) Run() error
Run implements the generic Create command
type CreateSpringOptions ¶
type CreateSpringOptions struct {
CreateProjectOptions
Advanced bool
SpringForm spring.SpringBootForm
}
CreateSpringOptions the options for the create spring command
func (*CreateSpringOptions) Run ¶
func (o *CreateSpringOptions) Run() error
Run implements the command