Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewCmdCreateQuickstart ¶
func NewCmdCreateQuickstart(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdCreateQuickstart creates a command object for the "create" command
func NewCmdCreateSpring ¶
func NewCmdCreateSpring(commonOpts *opts.CommonOptions) *cobra.Command
NewCmdCreateSpring creates a command object for the "create" command
Types ¶
type CreateQuickstartOptions ¶
type CreateQuickstartOptions struct {
Options
GitHubOrganisations []string
Filter quickstarts.QuickstartFilter
GitProvider gits.GitProvider
GitHost string
IgnoreTeam bool
}
CreateQuickstartOptions the options for the create quickstart command
func (*CreateQuickstartOptions) CreateQuickStart ¶
func (o *CreateQuickstartOptions) CreateQuickStart(q *quickstarts.QuickstartForm) error
CreateQuickStart helper method to create a quickstart from a quickstart resource
func (*CreateQuickstartOptions) Run ¶
func (o *CreateQuickstartOptions) Run() error
Run implements the generic Create command
type CreateSpringOptions ¶
type CreateSpringOptions struct {
Options
Advanced bool
SpringForm spring.SpringBootForm
}
CreateSpringOptions the options for the create spring command
func (*CreateSpringOptions) Run ¶
func (o *CreateSpringOptions) Run() error
Run implements the command
type Options ¶
type Options struct {
importcmd.ImportOptions
OutDir string
DisableImport bool
GithubAppInstalled bool
}
Options contains the command line options
func (*Options) ImportCreatedProject ¶
DoImport imports the project created at the given directory
type WizardOptions ¶
type WizardOptions struct {
options.CreateOptions
}
WizardOptions the options for the command
func NewCmdMain ¶
func NewCmdMain() (*cobra.Command, *WizardOptions)
NewCmdMain creates a command object for the command
func NewCmdMainWithOptions ¶
func NewCmdMainWithOptions(commonOpts *opts.CommonOptions) (*cobra.Command, *WizardOptions)
NewCmdMainWithOptions creates a command object for the command